function result = Mie_rain(fGHz, R, TK, distribution)

% Mie- extinction, scattering, absorption, backscattering 
% and asymmetric scattering coefficients in 1/km  
% for normalised drop-size distributions.  
% Input:
% fGHz: frequency in GHz,  range 1 to 1000 GHz
% R: Rain rate in mm/h,    range 0.1 to 100 mm/h
% TK: Temp. in K,          range 260 to 310 K
% distribution: 
% 'LP' for Laws-Parsons, 'MP' for Marshall-Palmer,
% 'JD' for Joss-Drizzle, or 'JT' for Joss-Thunderstorm
% C. Mtzler, Oct. 2002

nsteps=550;
nx=(1:nsteps)';
c0=299.793;
m=sqrt(epswater(fGHz, TK));
dD=0.01*R^(1/6)/fGHz^0.05;
D=0.01+nx*dD;
x=pi*D*fGHz/c0;
sigmag=pi*D.*D/4;
if distribution=='LP'
    NP=rainLP(R,D);
elseif distribution=='MP'
    NP=rainMP(R,D);
elseif distribution=='JD'
    NP=rainJD(R,D);
elseif distribution=='JT'
    NP=rainJT(R,D);
end;
    sn=sigmag.*NP*1000000;
    for j = 1:nsteps    
        a(j,:)=Mie(m,x(j));
    end;
    b(:,1)=D;
    b(:,2)=a(:,1).*sn;
    b(:,3)=a(:,2).*sn;
    b(:,4)=a(:,3).*sn;
    b(:,5)=a(:,4).*sn;
    b(:,6)=a(:,2).*a(:,5).*sn; 
    gext= sum(b(:,2))*dD;
    gsca= sum(b(:,3))*dD;
    gabs= sum(b(:,4))*dD;
    gb=   sum(b(:,5))*dD;
    gteta=sum(b(:,6))*dD;
    res=[gext gsca gabs gb gteta];
output_parameters='Gext, Gsca, Gabs, Gb, Gsca*<costeta>'
result=res;
