function result = Mie_rain1(fGHz, TK, nsteps, dD)

% Efficiencies of rain extinction, scattering, absorption 
% backscattering and asymmetric scattering versus droplet
% diameter D from 0 to nsteps*dD, using Mie Theory and
% the dielectric model of Liebe et al. (1991), see epswater.
% Input: fGHz frequency in GHz, TK temperature in K, nsteps number
% of diameters (D in mm), dD increment of diameter in mm 
% C. Mtzler, June 2002

m=sqrt(epswater(fGHz, TK));
nx=(1:nsteps)';
D=(nx-1)*dD;
c0=299.793;
x=pi*D*fGHz/c0;

for j = 1:nsteps
    a(j,:)=Mie(m,x(j));
    a_1(j,:)=Mie_1(m,x(j));  % Rayleigh Approximation
end;
a=[a(:,2:4),a_1(:,2)];
a=[a(:,1:4),a_1(:,3)];
a=[a(:,1:5),a_1(:,4)];
output_parameters='Qsca, Qabs, Qb, QscaR, QabsR, QbR'

% plotting the results
m1=real(m);m2=imag(m);
plot(D,a(:,1:6))
legend('Qsca','Qabs','Qb','QscaR','QabsR','QbR')
title(sprintf('Mie Efficiencies for raindrops f=%gGHz, T=%gK, m=%g+%gi',fGHz,TK,m1,m2))
xlabel('D (mm)')
ylabel('Mie Efficiency')

result=a; 