function result = Mie_rain4a(R, TK, fmin, fmax, nfreq, sel)

% Spectra of either extinction, scattering, absorption, 
% backscattering or asymmetric scattering coefficients
% in 1/km for the 4 drop-size distributions LP, MP, JD, JT
% using Mie Theory and dielectric Model of Liebe et al. 1991
% Input:
% R: rain rate in mm/h, TK: Temp. in K, 
% fmin, fmax: minimum and maximum frequency in GHz
% nfreq: Number of frequencies 
% sel='ext', 'sca', 'abs', 'b', or 'asy'
% C. Mtzler, June 2002, rev. Oct. 2002.

nsteps=550;
fact=(fmax/fmin)^(1/(nfreq-1));
fGHz=fmin/fact;
nx=(1:nsteps)';
c0=299.793;
for jr = 1:nfreq
    fGHz=fGHz*fact; f(jr)=fGHz;
    m=sqrt(epswater(fGHz, TK));
    dD=0.01*R^(1/6)/fGHz^0.05;
    D=nx*dD;
    x=pi*D*fGHz/c0;
    sigmag=pi*D.*D/4;
NLP=rainLP(R,D);
NMP=rainMP(R,D);
NJD=rainJD(R,D);
NJT=rainJT(R,D);
sn1=sigmag.*NLP*1000000;
sn2=sigmag.*NMP*1000000;
sn3=sigmag.*NJD*1000000;
sn4=sigmag.*NJT*1000000;
for j = 1:nsteps    
    a(j,:)=Mie(m,x(j));
end;
b(:,1)=a(:,1).*sn1; b(:,2)=a(:,1).*sn2; b(:,3)=a(:,1).*sn3; b(:,4)=a(:,1).*sn4;
b(:,5)=a(:,2).*sn1; b(:,6)=a(:,2).*sn2; b(:,7)=a(:,2).*sn3; b(:,8)=a(:,2).*sn4;
b(:,9)=a(:,3).*sn1; b(:,10)=a(:,3).*sn2; b(:,11)=a(:,3).*sn3; b(:,12)=a(:,3).*sn4;
b(:,13)=a(:,4).*sn1;b(:,14)=a(:,4).*sn2; b(:,15)=a(:,4).*sn3; b(:,16)=a(:,4).*sn4;
b(:,17)=a(:,2).*a(:,5).*sn1; b(:,18)=a(:,2).*a(:,5).*sn2; 
b(:,19)=a(:,2).*a(:,5).*sn3; b(:,20)=a(:,2).*a(:,5).*sn4; 
gext(jr,:)=[sum(b(:,1))*dD,sum(b(:,2))*dD,sum(b(:,3))*dD,sum(b(:,4))*dD];
gsca(jr,:)=[sum(b(:,5))*dD,sum(b(:,6))*dD,sum(b(:,7))*dD,sum(b(:,8))*dD];
gabs(jr,:)=[sum(b(:,9))*dD,sum(b(:,10))*dD,sum(b(:,11))*dD,sum(b(:,12))*dD];
gb(jr,:)=[sum(b(:,13))*dD,sum(b(:,14))*dD,sum(b(:,15))*dD,sum(b(:,16))*dD];
gasy(jr,:)=[sum(b(:,17))*dD,sum(b(:,18))*dD,sum(b(:,19))*dD,sum(b(:,20))*dD];
end;
% Plot of the selected parameters:
if sel=='ext'
    loglog(f,gext(:,1:4))
    legend('LP','MP','JD','JT')
    title(sprintf('R=%gmm/h, T=%gK',R,TK))
    xlabel('f (GHz)')
    ylabel('Gext(1/km)')
elseif sel=='sca'
    loglog(f,gsca(:,1:4))
    legend('LP','MP','JD','JT')
    title(sprintf('R=%gmm/h, T=%gK',R,TK))
    xlabel('f (GHz)')
    ylabel('Gsca(1/km)')
elseif sel=='abs'
    loglog(f,gabs(:,1:4))
    legend('LP','MP','JD','JT')
    title(sprintf('R=%gmm/h, T=%gK',R,TK))
    xlabel('f (GHz)')
    ylabel('Gabs(1/km)')
elseif sel=='b'
    loglog(f,gb(:,1:4))
    legend('LP','MP','JD','JT')
    title(sprintf('R=%gmm/h, T=%gK',R,TK))
    xlabel('f (GHz)')
    ylabel('Gb(1/km)')
elseif sel=='asy'
    loglog(f,gasy(:,1:4))
    legend('LP','MP','JD','JT')
    title(sprintf('R=%gmm/h, T=%gK',R,TK))
    xlabel('f (GHz)')
    ylabel('Gasy(1/km)')
end;
