function result = Mie_rain5(fGHz, R, nT, dT, dist)

% Extinction, scattering, absorption, backscattering and 
% asymmetric scattering coefficients in 1/km versus Temperature, 
% using Mie Theory, Input:
% fGHz: frequency in GHz, TK: Temp. in K, 
% nT: Number of temperatures
% dT: temperature increment
% dist='MP' for Marshall-Palmer (MP) distribution 
% dist='LP' for Laws-Parsons (LP) distribution 
% C. Mtzler, June 2002, rev. Oct. 2002.

Tmin=270;   
nsteps=551;
TK=Tmin-dT;
nx=(1:nsteps)';
c0=299.793;
for jr = 1:nT
    TK=TK+dT;
    m=sqrt(epswater(fGHz, TK));
    dD=0.01*R^(1/6)/fGHz^0.05;
    D=nx*dD;
    x=pi*D*fGHz/c0;
    sigmag=pi*D.*D/4;
if distribution=='LP'
    NP=rainLP(R,D);
elseif distribution=='MP'
    NP=rainMP(R,D);
elseif distribution=='JD'
    NP=rainJD(R,D);
elseif distribution=='JT'
    NP=rainJT(R,D);
end;
    sn=sigmag.*NP*1000000;
    for j = 1:nsteps    
        a(j,:)=Mie(m,x(j));
    end;
    b(:,1)=D;
    b(:,2)=a(:,1).*sn;
    b(:,3)=a(:,2).*sn;
    b(:,4)=a(:,3).*sn;
    b(:,5)=a(:,4).*sn;
    b(:,6)=a(:,2).*a(:,5).*sn; 
    gext= sum(b(:,2))*dD;
    gsca= sum(b(:,3))*dD;
    gabs= sum(b(:,4))*dD;
    gb=   sum(b(:,5))*dD;
    gteta=sum(b(:,6))*dD;
    res(jr,:)=[TK gext gsca gabs gb gteta];
end;
output_parameters='Gext, Gsca, Gabs, Gb, Gsca*<costeta>'
plot(res(:,1),res(:,2:6))
legend('Gext','Gsca','Gabs','Gb','Gsca*<costeta>')
title(sprintf('Propag. Coef. at f=%gGHz, R=%gmm/h, Distribution=%s',fGHz,R,dist))
xlabel('T (K)');    ylabel('Gi(1/km)')
result=res;
