function result = rainJT(R, D)

% Joss-Thunderstorm (JT) drop-size distribution  
% with normalisation by Matzler
% Input:
% R: Rain rate or line vector of rain rates, in mm/h 
% D: diameter or column vector of diameters, in mm
% C. Mtzler, Oct. 2002.

nsteps=length(D);
N0=0.014/10000;                % original MP N0 in 1/mm^4
x1=log(R);
x2=x1.*x1;
y=1.0945+0.00523*x1+0.0124*x2; % renorm. function 
yr=repmat(y,nsteps,1);
N0=N0.*yr;                     % Renormalised N0 in 1/mm^4
LA=3.0./R.^0.21;  
NMP=N0.*exp(-D*LA);            % Joss-Thunderstorm Distr.
% vfall=rainfallspeed(D);      % terminal fall speed
% volg=(pi/6)*D.^3;            % drop volume in mm^3, used
% y=volg.*vfall;               % for test of normalisation
% flux=3600000*dD*y'*NMP;      % volume flux = rain rate
% Nrenor=R./flux;              % renormalisation factor
% result=[log(R);R;Nrenor]';
result=NMP;