function result = raintestLP(tn, dD)

% Test of Laws and Parsons (LP) drop-size distribution 
% of de Wolf, Radio Sci. 36, 639 (2001), Equation (7)
% but with additional renormalisation, s. Factor y.
% Test results to be plotted and returned.
% Input:
% tn: Test number (0,1,2,3,4,5)
% dD incremental diameter for plot of distr. function, in mm
% C. Mtzler, Oct. 2002.
% Data from Burros and Attwood, 149, Table 23.2 in 
% M.I.Skolnik, Radar Handbook, 2nd Edition, 1990:
ba0=[0,28,50.1,18.2,3,.7;0 ,0.5,1.,1.5,2,2.5]; 
ba1=[0,10.9,37.1,31.3,13.5,4.9,1.5,0.6,0.2;0,0.5,1.,1.5,2,2.5,3,3.5,4];
ba2=[0,7.3,27.8,32.8,19,7.9,3.3,1.1,.6,.2;0,.5,1,1.5,2,2.5,3,3.5,4,4.5];
ba3=[0,2.6,11.5,24.5,25.4,17.3,10.1,4.3,2.3,1.2,0.6,0.2;
    0,0.5,1.,1.5,2,2.5,3,3.5,4,4.5,5,5.5];
ba4=[0,1.7,7.6,18.4,23.9,19.9,12.8,8.2,3.5,2.1,1.1,0.5,0.2;
    0,0.5,1.,1.5,2,2.5,3,3.5,4,4.5,5,5.5,6];
ba5=[0,1.2,5.4,12.5,19.9,20.9,15.6,10.9,6.7,3.3,1.8,1.1,0.5,0.2;
    0,0.5,1.,1.5,2,2.5,3,3.5,4,4.5,5,5.5,6,6.5];
ba6=[0,1,4.6,8.8,13.9,17.1,18.4,15,9,5.8,3,1.7,1,0.7;
    0,0.5,1.,1.5,2,2.5,3,3.5,4,4.5,5,5.5,6,6.5];

if tn==0  % Selection of baj, tn=j=0 to 6 (for R=0.25 to 100 mm/h):
    a=ba0'; R=0.25;
elseif tn==1
    a=ba1'; R=1.25;
elseif tn==2
    a=ba2'; R=2.5;
elseif tn==3
    a=ba3'; R=12.5;
elseif tn==4
    a=ba4'; R=25;
elseif tn==5
    a=ba5'; R=50;
elseif tn==6
    a=ba6'; R=100;
end;
D=a(:,2); 
nsteps=length(D); 
Dmx=ceil(D(nsteps));      
len=length(R);
y=max(1,1-0.058*log(R/2.2));
yr=repmat(y,nsteps,1);
N0=(pi/6)*1.98e-5*(D.^5.93)*R.^-0.384;
N0=N0.*yr;
LA=5.38./R.^0.186;
NLP=N0.*exp(-D*LA);         % Normalised LP Distribution Function
v=sum(NLP)*0.5;
a=[50*NLP/v,a];
Dc=(0.0:dD:Dmx)';           % vector of quasi-continous D values
fLP=rainLP(R,Dc);           % quasi-continous LP function of de Wolf
D3=(pi/6)*(Dc.^3);          % sphere volume
df=100*D3.*fLP;             % Percent contribution
fv=dD*(pi/6)*(Dc.^3)'*fLP;  % volume fraction of rain water
f=0.5*df/fv;                % Percent values for dD=0.5mm
plot(Dc,f,'r-',D,a(:,2),'bo--')
legend('LP','Burrows-Attwood')
title(sprintf('Delta-F, R=%gmm/h',R))
xlabel('D, mm')
result=a;     % col 1: baj,  col 2: LP fitted by de Wolf, Col 3: D(mm)